@@ -584,9 +584,9 @@ eval_cond_stats_parity <- function(data, outcome, group,
   }
 }
 
-#' Examine Predictive Parity of a Model
+#' Examine Positive Predictive Parity of a Model
 #'
-#' This function evaluates *predictive parity (PP)*, a key fairness criterion that
+#' This function evaluates *positive predictive predictive parity*, a key fairness criterion that
 #' compares the *Positive Predictive Value (PPV)* between groups defined by a sensitive attribute.
 #' In other words, it assesses whether, among individuals predicted to be positive,
 #' the probability of being truly positive is equal across subgroups.
@@ -638,8 +638,8 @@ eval_cond_stats_parity <- function(data, outcome, group,
 #' # We will use sex as the sensitive attribute and day_28_flg as the outcome.
 #' # We choose threshold = 0.41 so that the overall FPR is around 5%.
 #'
-#' # Evaluate Predictive Parity
-#' eval_pred_parity(
+#' # Evaluate Positive Predictive Parity
+#' eval_pos_pred_parity(
 #'   data = test_data,
 #'   outcome = "day_28_flg",
 #'   group = "gender",
@@ -647,9 +647,10 @@ eval_cond_stats_parity <- function(data, outcome, group,
 #'   cutoff = 0.41
 #' )
 #' }
+#' @seealso \code{\link{eval_neg_pred_parity}}
 #' @export
 
-eval_pred_parity <- function(data, outcome, group, probs, cutoff = 0.5, confint = TRUE,
+eval_pos_pred_parity <- function(data, outcome, group, probs, cutoff = 0.5, confint = TRUE,
                              bootstraps = 2500, alpha = 0.05,
                              digits = 2, message = TRUE) {
   # Check if outcome is binary
@@ -706,16 +707,150 @@ eval_pred_parity <- function(data, outcome, group, probs, cutoff = 0.5, confint
 
   if (message) {
     if (lower_ci > 0 || upper_ci < 0) {
-      cat("There is evidence that model does not satisfy predictive parity.\n")
+      cat("There is evidence that model does not satisfy positive predictive parity.\n")
     } else {
-      cat("There is not enough evidence that the model does not satisfy
-            predictive parity.\n")
+      cat("There is not enough evidence that the model does not satisfy positive predictive parity.\n")
     }
   }
 
   return(result_df)
 }
 
+
+
+#' Examine Negative Predictive Parity of a Model
+#'
+#' This function evaluates *negative predictive predictive parity*, a key fairness criterion that
+#' compares the *Negative Predictive Value (NPV)* between groups defined by a sensitive attribute.
+#' In other words, it assesses whether, among individuals predicted to be negative,
+#' the probability of being truly negative is equal across subgroups.
+#'
+#' @param data Data frame containing the outcome, predicted outcome, and
+#' sensitive attribute
+#' @param outcome Name of the outcome variable, it must be binary
+#' @param group Name of the sensitive attribute
+#' @param probs Name of the predicted outcome variable
+#' @param cutoff Threshold for the predicted outcome, default is 0.5
+#' @param confint Whether to compute 95% confidence interval, default is TRUE
+#' @param bootstraps Number of bootstrap samples, default is 2500
+#' @param alpha The 1 - significance level for the confidence interval, default is 0.05
+#' @param digits Number of digits to round the results to, default is 2
+#' @param message Whether to print the results, default is TRUE
+#' @return A list containing the following elements:
+#'  - NPV_Group1: Negative Predictive Value for the first group
+#'  - NPV_Group2: Negative Predictive Value for the second group
+#'  - NPV_Diff: Difference in Negative Predictive Value
+#'  - NPV_Ratio: Ratio in Negative Predictive Value
+#'  If confidence intervals are computed (`confint = TRUE`):
+#'  - NPV_Diff_CI: A vector of length 2 containing the lower and upper bounds
+#'  of the 95% confidence interval for the difference in Negative Predictive
+#'  Value
+#'  - NPV_Ratio_CI: A vector of length 2 containing the lower and upper bounds
+#'  of the 95% confidence interval for the ratio in Negative Predictive
+#'  Value
+#' @importFrom stats qnorm sd
+#' @examples
+#' \donttest{
+#' library(fairmetrics)
+#' library(dplyr)
+#' library(magrittr)
+#' library(randomForest)
+#' data("mimic_preprocessed")
+#' set.seed(123)
+#' train_data <- mimic_preprocessed %>%
+#'   dplyr::filter(dplyr::row_number() <= 700)
+#' # Fit a random forest model
+#' rf_model <- randomForest::randomForest(factor(day_28_flg) ~ ., data = train_data, ntree = 1000)
+#' # Test the model on the remaining data
+#' test_data <- mimic_preprocessed %>%
+#'   dplyr::mutate(gender = ifelse(gender_num == 1, "Male", "Female")) %>%
+#'   dplyr::filter(dplyr::row_number() > 700)
+#'
+#' test_data$pred <- predict(rf_model, newdata = test_data, type = "prob")[, 2]
+#'
+#' # Fairness evaluation
+#' # We will use sex as the sensitive attribute and day_28_flg as the outcome.
+#' # We choose threshold = 0.41 so that the overall FPR is around 5%.
+#'
+#' # Evaluate Negative Predictive Parity
+#' eval_neg_pred_parity(
+#'   data = test_data,
+#'   outcome = "day_28_flg",
+#'   group = "gender",
+#'   probs = "pred",
+#'   cutoff = 0.41
+#' )
+#' }
+#' @seealso \code{\link{eval_pos_pred_parity}}
+#' @export
+
+eval_neg_pred_parity <- function(data, outcome, group, probs, cutoff = 0.5, confint = TRUE,
+                                 bootstraps = 2500, alpha = 0.05,
+                                 digits = 2, message = TRUE) {
+  # Check if outcome is binary
+  unique_values <- sort(unique(data[[outcome]]))
+  if (!(length(unique_values) == 2 && all(unique_values %in% c(0, 1)))) {
+    stop("Outcome must be binary (containing only 0 and 1).")
+  }
+
+  npv <- get_npv(
+    data = data, outcome = outcome, group = group, probs = probs,
+    cutoff = cutoff, digits = digits
+  )
+  npv_dif <- npv[[1]] - npv[[2]]
+  npv_ratio <- npv[[1]] / npv[[2]]
+
+  se <- replicate(bootstraps, {
+    group1 <- sample(which(data[[group]] == sort(unique(data[[group]]))[1]),
+                     replace = TRUE
+    )
+    group2 <- sample(which(data[[group]] == sort(unique(data[[group]]))[2]),
+                     replace = TRUE
+    )
+    data_boot <- rbind(data[group1, ], data[group2, ])
+    npv_boot <- get_ppv(
+      data = data_boot, outcome = outcome, group = group, probs = probs,
+      cutoff = cutoff, digits = digits
+    )
+    return(c(npv_boot[[1]] - npv_boot[[2]], log(npv_boot[[1]] / npv_boot[[2]])))
+  })
+
+  lower_ci <- round(npv_dif - qnorm(1 - alpha / 2) * sd(se[1, ]), digits)
+  upper_ci <- round(npv_dif + qnorm(1 - alpha / 2) * sd(se[1, ]), digits)
+  lower_ratio_ci <- round(exp(log(npv_ratio) - qnorm(1 - alpha / 2) * sd(se[2, ])), digits)
+  upper_ratio_ci <- round(exp(log(npv_ratio) + qnorm(1 - alpha / 2) * sd(se[2, ])), digits)
+
+  result_df <- data.frame(
+    "NPV",
+    npv[[1]],
+    npv[[2]],
+    npv_dif,
+    paste0("[", lower_ci, ", ", upper_ci, "]"),
+    round(npv_ratio, digits),
+    paste0("[", lower_ratio_ci, ", ", upper_ratio_ci, "]")
+  )
+  colnames(result_df) <- c(
+    "Metric",
+    paste0("Group", sort(unique(data[[group]]))[1]),
+    paste0("Group", sort(unique(data[[group]]))[2]),
+    "Difference",
+    "95% Diff CI",
+    "Ratio",
+    "95% Ratio CI"
+  )
+
+  if (message) {
+    if (lower_ci > 0 || upper_ci < 0) {
+      cat("There is evidence that model does not satisfy negative predictive parity.\n")
+    } else {
+      cat("There is not enough evidence that the model does not satisfy negative predictive parity.\n")
+    }
+  }
+
+  return(result_df)
+}
+
+
 #' Examine Predictive Equality of a Model
 #'
 #' This function evaluates predictive equality, a fairness metric that compares the
@@ -777,7 +912,7 @@ eval_pred_parity <- function(data, outcome, group, probs, cutoff = 0.5, confint
 #'   cutoff = 0.41
 #' )
 #' }
-#' @seealso \code{\link{eval_pred_parity}}, \code{\link{eval_stats_parity}}
+#' @seealso \code{\link{eval_pos_pred_parity}},  \code{\link{eval_neg_pred_parity}}, \code{\link{eval_stats_parity}}
 #' @export
 
 eval_pred_equality <- function(data, outcome, group, probs, cutoff = 0.5, confint = TRUE,
@@ -1191,7 +1326,7 @@ eval_acc_parity <- function(data, outcome, group, probs, cutoff = 0.5, confint =
 #' )
 #' }
 #'
-#' @seealso \code{\link{eval_acc_parity}}, \code{\link{eval_cond_acc_equality}}, \code{\link{eval_pred_parity}}
+#' @seealso \code{\link{eval_acc_parity}}, \code{\link{eval_cond_acc_equality}}, \code{\link{eval_pos_pred_parity}},  \code{\link{eval_neg_pred_parity}}
 #' @export
 
 eval_bs_parity <- function(data, outcome, group, probs, confint = TRUE,
@@ -1330,7 +1465,7 @@ eval_bs_parity <- function(data, outcome, group, probs, confint = TRUE,
 #'   message = FALSE
 #' )
 #' }
-#' @seealso \code{\link{eval_acc_parity}}, \code{\link{eval_bs_parity}}, \code{\link{eval_pred_parity}}
+#' @seealso \code{\link{eval_acc_parity}}, \code{\link{eval_bs_parity}}, \code{\link{eval_pos_pred_parity}},  \code{\link{eval_neg_pred_parity}}
 #' @export
 
 eval_treatment_equality <- function(data, outcome, group, probs, cutoff = 0.5, confint = TRUE,
